@@ -26,7 +26,7 @@
 #include <QGst/Init>
 int main(int argc, char *argv[])
 {
-    KAboutData about("kamoso", i18n("Kamoso"), "3.2.0", i18n("Utility for taking photos and videos using a webcam"),
+    KAboutData about("kamoso", i18n("Kamoso"), "3.2.2", i18n("Utility for taking photos and videos using a webcam"),
                 KAboutLicense::GPL, i18n("(C) 2008-2015 Alex Fiestas and Aleix Pol"));
 
     about.addAuthor( i18n("Aleix Pol Gonzalez"), i18n("Semaphore hacker"), "aleixpol@kde.org" );
@@ -41,6 +41,11 @@ int main(int argc, char *argv[])
     }
 
     WebcamControl webcamControl;
+    if (!webcamControl.play()) {
+        qWarning() << "Unrecoverable error occurred when initializing webcam. Exiting.";
+        QApplication::exit(1);
+        return 1;
+    }
 
     QObject::connect(&app, &QCoreApplication::aboutToQuit, &webcamControl, &WebcamControl::stop);
 
